import subprocess
import json


def get_video_info(video_path):
    # 使用 ffprobe 获取视频信息
    command = [
        'ffprobe',
        '-v', 'error',
        '-select_streams', 'v:0',
        '-show_entries', 'format=size,bit_rate',
        '-of', 'json',
        video_path
    ]
    result = subprocess.run(command, stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True)

    if result.returncode != 0:
        print(f"Error: {result.stderr}")
        return None

    # 解析 JSON 输出
    video_info = json.loads(result.stdout)
    return video_info['format']


if __name__ == "__main__":
    # video_path = 'path/to/your/video.mp4'
    video_path = 'http://rescdn.yishihui.com/longvideo/multitranscodeh265/crawler_local/video/prod/20250301/088c1f984789aa3ef65aa7e41018237f7446740420250301194002586558054-2SD.mp4'
    info = get_video_info(video_path)

    if info:
        size = int(info['size'])
        bit_rate = int(info['bit_rate'])

        print(f"File Size: {size / (1024 * 1024):.2f} MB")
        print(f"Bit Rate: {bit_rate / 1000:.2f} kbps")